@@ -6,7 +6,7 @@
 ## TODO: what to do with mapper_args, reducer_args?
 ## TODO: what if you want to supply more than 1 mapper/reducer function?
 hive_stream <- function( mapper, reducer, input, output, henv = hive(),
-                         mapper_args = NULL, reducer_args = NULL, cmdenv_arg=NULL ) {
+                         mapper_args = NULL, reducer_args = NULL, cmdenv_arg=NULL, streaming_args=NULL) {
   ## check directories in DFS
   stopifnot( DFS_dir_exists(input, henv) )
 
@@ -23,11 +23,12 @@ hive_stream <- function( mapper, reducer, input, output, henv = hive(),
   stopifnot( file.exists(mapper_exec) )
   ## now the reducer (if available)
   reducer_exec <- NULL
-  streaming_args <- "mapred.reduce.tasks=0"
+  if( is.null(streaming_args) )
+      streaming_args <- "-D mapred.reduce.tasks=0"
   if( !is.null(reducer) ){
     .hadoop_check_function_sanity( reducer )
     ## set additional args to Hadoop Streaming
-    streaming_args <- sprintf( "mapred.reduce.tasks=%d", hive_get_nreducer(henv) )
+    streaming_args <- paste( sprintf("-D mapred.reduce.tasks=%d", hive_get_nreducer(henv)), streaming_args, collapse = " " )
     reducer_exec <- .generate_executable( reducer, .get_hadoop_executable(type = "reducer") )
     stopifnot( file.exists(reducer_exec) )
   }
@@ -57,7 +58,7 @@ hive_stream <- function( mapper, reducer, input, output, henv = hive(),
     cmdenv_arg <- ""
   else
     cmdenv_arg <- sprintf( "-cmdenv '%s'", paste(as.character(cmdenv_arg), collapse = " ") )
-  out <- system(sprintf('%s jar %s -D %s -input %s -output %s %s %s %s %s',
+  out <- system(sprintf('%s jar %s %s -input %s -output %s %s %s %s %s',
                  hadoop(henv), hadoop_streaming(henv), streaming_args, input, output,
                  mapper_arg, reducer_arg, files, cmdenv_arg),
          intern = TRUE)
